# pyintersection

Overview
----------------------
The pyintersection module provides a set of functions for finding intersections of manifolds.

Installation
----------------------
The module requires a ``numpy`` module to work. If you don't have ``numpy`` installed, use the following command to install it:

    pip install numpy
    
If ``numpy`` is installed, then first you need to clone the repository to your computer. To do this, you can use the command below:

    git clone https://github.com/suspiciousFruit/pyintersection.git pyintersection
    
Then go to the directory with the project:

    cd pyintersection

And finally use the following command to install module:

    python setup.py install
